using System;
using MySql.Data.MySqlClient;
using NUnit.Framework;


namespace ByteFXNUnit
{
	/// <summary>
	/// This fixture exhibits the System.Overflow exception when I try to read a year data type.
	/// The test uses a mysql database with a table called "tblyear" with 2 fields, an auto id field called
	/// "AutoId" and a Year(4) data type field, called "YearField". Appropriate access priviliges are needed to
	/// execute an INSERT, SELECT, and TRUNCATE.
	/// 
	/// Before running these tests, edit the connection string below to connect to your database.
	/// </summary>
	[TestFixture]
	public class YearDatatypeFixture
	{
		private MySqlCommand _cmd;
		static string _table = "tblyear";
		static string _year = "2002";
		static string _connectionString = "Data Source=192.168.168.154;Database=test;User ID=test_user;Password=test_user;";

		[SetUp]
		public void Setup()
		{
			string sql = "TRUNCATE TABLE " + _table;
			_cmd = new MySqlCommand(sql, new MySqlConnection(_connectionString));
			_cmd.Connection.Open();
			_cmd.ExecuteNonQuery();
			_cmd.CommandText = "INSERT INTO " + _table + " (YearField) VALUES ('" + _year + "')";
			_cmd.ExecuteNonQuery();
		}

		[TearDown]
		public void TearDown()
		{
			_cmd.Connection.Close();
			_cmd = null;
		}

		[Test]
		public void YearDataTypeTest()
		{
			ColumnTest(_year, "YearField");
		}

		[Test]
		public void AutoIdTest()
		{
			ColumnTest("1", "AutoId");
		}

		private void ColumnTest(string expectedValue, string columnName)
		{
			string sql = "SELECT " + columnName + " FROM " + _table;
			_cmd.CommandText = sql;
			MySqlDataReader _reader = _cmd.ExecuteReader();
			_reader.Read();
			Assert.AreEqual(expectedValue, _reader[columnName].ToString());
			_reader.Close();
			_reader = null;
		}
	}
}
